@@ -5,7 +5,6 @@ use object::*;
 //enum PyLongObject { /* representation hidden */ }
 
 
-#[link(name = "python2.7")]
 extern "C" {
     pub static mut PyLong_Type: PyTypeObject;
 }
@@ -21,7 +20,6 @@ pub unsafe fn PyLong_CheckExact(op : *mut PyObject) -> c_int {
     (Py_TYPE(op) == u) as c_int
 }
 
-#[link(name = "python2.7")]
 extern "C" {
     pub fn PyLong_FromLong(v: c_long) -> *mut PyObject;
     pub fn PyLong_FromUnsignedLong(v: c_ulong) -> *mut PyObject;
@@ -34,7 +32,7 @@ extern "C" {
     pub fn PyLong_FromString(str: *mut c_char,
                              pend: *mut *mut c_char,
                              base: c_int) -> *mut PyObject;
-    #[cfg(feature="Py_USING_UNICODE")]
+    #[cfg(py_sys_config="Py_USING_UNICODE")]
     pub fn PyLong_FromUnicode(u: *mut ::unicodeobject::Py_UNICODE, length: Py_ssize_t,
                               base: c_int) -> *mut PyObject;
     pub fn PyLong_FromVoidPtr(p: *mut c_void) -> *mut PyObject;
