@@ -2,7 +2,6 @@ use libc::{c_int, c_char};
 use pyport::Py_ssize_t;
 use object::*;
 
-#[link(name = "python2.7")]
 extern "C" {
     pub static mut PyMemoryView_Type: PyTypeObject;
 }
@@ -24,7 +23,6 @@ pub unsafe fn PyMemoryView_GET_BASE(op : *mut PyObject) -> *mut PyObject {
 }
 
 
-#[link(name = "python2.7")]
 extern "C" {
     pub fn PyMemoryView_GetContiguous(base: *mut PyObject,
                                       buffertype: c_int,
@@ -36,9 +34,9 @@ extern "C" {
 #[repr(C)]
 #[derive(Copy, Clone)]
 pub struct PyMemoryViewObject {
-    #[cfg(feature="Py_TRACE_REFS")]
+    #[cfg(py_sys_config="Py_TRACE_REFS")]
     pub _ob_next: *mut PyObject,
-    #[cfg(feature="Py_TRACE_REFS")]
+    #[cfg(py_sys_config="Py_TRACE_REFS")]
     pub _ob_prev: *mut PyObject,
     pub ob_refcnt: Py_ssize_t,
     pub ob_type: *mut PyTypeObject,
