@@ -6,9 +6,9 @@ use methodobject::PyMethodDef;
 #[repr(C)]
 #[derive(Copy, Clone)]
 pub struct PyObject {
-    #[cfg(feature="Py_TRACE_REFS")]
+    #[cfg(py_sys_config="Py_TRACE_REFS")]
     pub _ob_next: *mut PyObject,
-    #[cfg(feature="Py_TRACE_REFS")]
+    #[cfg(py_sys_config="Py_TRACE_REFS")]
     pub _ob_prev: *mut PyObject,
     pub ob_refcnt: Py_ssize_t,
     pub ob_type: *mut PyTypeObject,
@@ -17,9 +17,9 @@ pub struct PyObject {
 #[repr(C)]
 #[derive(Copy, Clone)]
 pub struct PyVarObject {
-    #[cfg(feature="Py_TRACE_REFS")]
+    #[cfg(py_sys_config="Py_TRACE_REFS")]
     pub _ob_next: *mut PyObject,
-    #[cfg(feature="Py_TRACE_REFS")]
+    #[cfg(py_sys_config="Py_TRACE_REFS")]
     pub _ob_prev: *mut PyObject,
     pub ob_refcnt: Py_ssize_t,
     pub ob_type: *mut PyTypeObject,
@@ -413,7 +413,6 @@ impl Clone for PyTypeObject {
     #[inline] fn clone(&self) -> PyTypeObject { *self }
 }
 
-/* PyHeapTypeObject omitted, it doesn't seem to be part of the documented API
 #[repr(C)]
 #[derive(Copy)]
 pub struct PyHeapTypeObject {
@@ -426,13 +425,17 @@ pub struct PyHeapTypeObject {
     pub ht_slots: *mut PyObject,
 }
 
+impl Clone for PyHeapTypeObject {
+    #[inline] fn clone(&self) -> PyHeapTypeObject { *self }
+}
+
 // access macro to the members which are floating "behind" the object
-#define PyHeapType_GET_MEMBERS(etype) \
-    ((PyMemberDef *)(((char *)etype) + Py_TYPE(etype)->tp_basicsize))
-*/
+#[inline]
+pub unsafe fn PyHeapType_GET_MEMBERS(etype: *mut PyHeapTypeObject) -> *mut ::structmember::PyMemberDef {
+    let basicsize = (*Py_TYPE(etype as *mut PyObject)).tp_basicsize;
+    (etype as *mut u8).offset(basicsize as isize) as *mut ::structmember::PyMemberDef
+}
 
-
-#[link(name = "python2.7")]
 extern "C" {
     pub fn PyType_IsSubtype(a: *mut PyTypeObject, b: *mut PyTypeObject) -> c_int;
 }
@@ -442,7 +445,6 @@ pub unsafe fn PyObject_TypeCheck(ob: *mut PyObject, tp: *mut PyTypeObject) -> c_
     (Py_TYPE(ob) == tp || PyType_IsSubtype(Py_TYPE(ob), tp) != 0) as c_int
 }
 
-#[link(name = "python2.7")]
 extern "C" {
     pub static mut PyType_Type: PyTypeObject;
     pub static mut PyBaseObject_Type: PyTypeObject;
@@ -459,7 +461,6 @@ pub unsafe fn PyType_CheckExact(op: *mut PyObject) -> c_int {
     (Py_TYPE(op) == (&mut PyType_Type as *mut _)) as c_int
 }
 
-#[link(name = "python2.7")]
 extern "C" {
     pub fn PyType_Ready(t: *mut PyTypeObject) -> c_int;
     pub fn PyType_GenericAlloc(t: *mut PyTypeObject, nitems: Py_ssize_t)
@@ -487,9 +488,8 @@ pub unsafe fn PyObject_Bytes(o: *mut PyObject) -> *mut PyObject {
     PyObject_Str(o)
 }
 
-#[link(name = "python2.7")]
 extern "C" {
-    #[cfg(feature="Py_USING_UNICODE")]
+    #[cfg(py_sys_config="Py_USING_UNICODE")]
     pub fn PyObject_Unicode(o: *mut PyObject) -> *mut PyObject;
     
     pub fn PyObject_Compare(arg1: *mut PyObject, arg2: *mut PyObject)
@@ -642,7 +642,7 @@ pub unsafe fn PyType_FastSubclass(t : *mut PyTypeObject, f : c_long) -> c_int {
 // Reference counting macros.
 #[inline(always)]
 pub unsafe fn Py_INCREF(op : *mut PyObject) {
-    if cfg!(feature="Py_REF_DEBUG") {
+    if cfg!(py_sys_config="Py_REF_DEBUG") {
         Py_IncRef(op)
     } else {
         (*op).ob_refcnt += 1
@@ -651,7 +651,7 @@ pub unsafe fn Py_INCREF(op : *mut PyObject) {
 
 #[inline(always)]
 pub unsafe fn Py_DECREF(op: *mut PyObject) {
-    if cfg!(feature="Py_REF_DEBUG") || cfg!(feature="COUNT_ALLOCS") {
+    if cfg!(py_sys_config="Py_REF_DEBUG") || cfg!(py_sys_config="COUNT_ALLOCS") {
         Py_DecRef(op)
     } else {
         (*op).ob_refcnt -= 1;
@@ -684,7 +684,6 @@ pub unsafe fn Py_XDECREF(op : *mut PyObject) {
     }
 }
 
-#[link(name = "python2.7")]
 extern "C" {
     pub fn Py_IncRef(o: *mut PyObject);
     pub fn Py_DecRef(o: *mut PyObject);
@@ -711,7 +710,6 @@ pub const Py_NE : c_int = 3;
 pub const Py_GT : c_int = 4;
 pub const Py_GE : c_int = 5;
 
-#[link(name = "python2.7")]
 extern "C" {
     fn _PyTrash_thread_deposit_object(o: *mut PyObject);
     fn _PyTrash_thread_destroy_chain();
