@@ -5,9 +5,9 @@ use object::*;
 #[repr(C)]
 #[allow(missing_copy_implementations)]
 struct PyStringObject {
-    #[cfg(feature="Py_TRACE_REFS")]
+    #[cfg(py_sys_config="Py_TRACE_REFS")]
     pub _ob_next: *mut PyObject,
-    #[cfg(feature="Py_TRACE_REFS")]
+    #[cfg(py_sys_config="Py_TRACE_REFS")]
     pub _ob_prev: *mut PyObject,
     pub ob_refcnt: Py_ssize_t,
     pub ob_type: *mut PyTypeObject,
@@ -17,7 +17,6 @@ struct PyStringObject {
     pub ob_sval: [c_char; 1],
 }
 
-#[link(name = "python2.7")]
 extern "C" {
     pub static mut PyBaseString_Type: PyTypeObject;
     pub static mut PyString_Type: PyTypeObject;
@@ -46,7 +45,6 @@ pub unsafe fn PyString_AS_STRING(op : *mut PyObject) -> *mut c_char {
     (*(op as *mut PyStringObject)).ob_sval.as_mut_ptr()
 }
 
-#[link(name = "python2.7")]
 extern "C" {
     pub fn PyString_FromString(v: *const c_char) -> *mut PyObject;
     pub fn PyString_FromStringAndSize(v: *const c_char,
